@@ -34,10 +34,12 @@ import System.Process ( runProcess, runInteractiveProcess, waitForProcess )
 import Control.Concurrent ( forkIO, newEmptyMVar, putMVar, takeMVar )
 import Control.Exception ( bracket, try, finally )
 import Data.Char ( toUpper )
-import Foreign.C ( CString, withCString, CInt )
+import Foreign.C ( CString, withCString )
 import Foreign.Ptr ( nullPtr )
-#ifdef HAVE_CURSES
-import Foreign.C ( CChar )
+#ifdef HAVE_TERMINFO
+import System.Console.Terminfo( tiGetNum, setupTermFromEnv, getCapability )
+#elif HAVE_CURSES
+import Foreign.C ( CChar, CInt )
 import Foreign.Ptr ( Ptr )
 import Foreign.Marshal.Alloc (allocaBytes)
 import Autoconf ( use_color )
@@ -46,6 +48,7 @@ import Workaround ( createLink, createDirectoryIfMissing )
 
 import Darcs.Flags ( DarcsFlag( SignAs, Sign, SignSSL, NoLinks,
                                 Verify, VerifySSL ) )
+import Darcs.RepoPath ( AbsolutePath, toFilePath )
 import Darcs.Utils ( withCurrentDirectory, breakCommand, get_viewer, ortryrunning, )
 import Darcs.Progress ( withoutProgress, progressList, debugMessage )
 import FastPackedString ( PackedString, readFilePS, gzReadFilePS, writeFilePS,
@@ -57,12 +60,11 @@ import Darcs.Lock ( withTemp, withOpenTemp, tempdir_loc, canonFilename, writeDoc
                     removeFileMayNotExist, )
 import CommandLine ( parseCmd, addUrlencoded )
 import Autoconf ( have_libcurl, have_libwww, have_HTTP, have_sendmail, have_mapi, sendmail_path, darcs_version )
-import qualified URL ( copyUrl, copyUrlFirst, waitUrl )
-import qualified HTTP ( copyUrl, exists )
+import URL ( copyUrl, copyUrlFirst, waitUrl )
 import Ssh ( getSSH, copySSH, copySSHs, SSHCmd(..) )
 import URL ( Cachable(..) )
 import Exec ( exec, Redirect(..), withoutNonBlock )
-import FileName ( fn2fp, fp2fn, norm_path )
+import UglyFileName ( fn2fp, fp2fn, norm_path )
 import Darcs.URL ( is_file, is_url, is_ssh )
 import Darcs.Utils ( catchall )
 import Printer ( Doc, Printers, putDocLnWith, hPutDoc, hPutDocLn, hPutDocWith, ($$), (<+>), renderPS,
@@ -199,8 +201,8 @@ speculateRemote u v =
     do maybeget <- maybeURLCmd "GET" u
        case maybeget of
          Just _ -> return () -- can't pipeline these
-         Nothing -> if have_libwww || have_libcurl
-                    then URL.copyUrl u v Cachable
+         Nothing -> if have_libwww || have_libcurl || have_HTTP
+                    then copyUrl u v Cachable
                     else return ()
 
 copyRemote :: String -> FilePath -> Cachable -> IO ()
@@ -215,11 +217,9 @@ copyRemote u v cache =
                   fail $ "(" ++ get ++ ") failed to fetch: " ++ u
 
 copyRemoteNormal :: String -> FilePath -> Cachable -> IO ()
-copyRemoteNormal u v cache = if have_libwww || have_libcurl
-                             then URL.copyUrlFirst u v cache >> URL.waitUrl u
-                             else if HTTP.exists
-                                  then HTTP.copyUrl u v cache
-                                  else copyRemoteCmd u v
+copyRemoteNormal u v cache = if have_libwww || have_libcurl || have_HTTP
+                             then copyUrlFirst u v cache >> waitUrl u
+                             else copyRemoteCmd u v
 
 copyFilesOrUrls :: [DarcsFlag]->FilePath->[String]->FilePath->Cachable->IO ()
 copyFilesOrUrls opts dou ns out _ | is_file dou = copyLocals opts dou ns out
@@ -269,12 +269,10 @@ mgetRemotes mget u ns d = do
 
 copyRemotesNormal :: String -> [String] -> FilePath -> Cachable -> IO()
 copyRemotesNormal u ns d cache =
-    if have_libwww || have_libcurl
-    then do mapM_ (\n -> URL.copyUrl (u++"/"++n) (d++"/"++n) cache) ns
-            doWithPatches (\n -> URL.waitUrl (u++"/"++n)) ns
-    else if have_HTTP
-         then doWithPatches (\n -> copyRemote (u++"/"++n) (d++"/"++n) cache) ns
-         else wgetRemotes u ns d
+    if have_libwww || have_libcurl || have_HTTP
+    then do mapM_ (\n -> copyUrl (u++"/"++n) (d++"/"++n) cache) ns
+            doWithPatches (\n -> waitUrl (u++"/"++n)) ns
+    else wgetRemotes u ns d
 
 -- Argh, this means darcs get will fail if we don't have libcurl and don't
 -- have wget.  :(
@@ -396,28 +394,35 @@ generateEmail h f t s cc body = do
 
 -- | Send an email, optionally containing a patch bundle
 --   (more precisely, its description and the bundle itself)
-sendEmailDoc :: String -> String -> String -> String -> String
-             -> Maybe (Doc, Doc) -> Doc -> IO ()
+sendEmailDoc
+  :: String           -- ^ from
+  -> String           -- ^ to
+  -> String           -- ^ subject
+  -> String           -- ^ cc
+  -> String           -- ^ send command
+  -> Maybe (Doc, Doc) -- ^ (content,bundle)
+  -> Doc              -- ^ body
+  -> IO ()
 sendEmailDoc _ "" _ "" _ _ _ = return ()
 sendEmailDoc f "" s cc scmd mbundle body =
   sendEmailDoc f cc s "" scmd mbundle body
 sendEmailDoc f t s cc scmd mbundle body =
   if have_sendmail || scmd /= "" then do
     withOpenTemp $ \(h,fn) -> do
-     generateEmail h f t s cc body
-     hClose h
-     ftable' <- case mbundle of
-                Just (content,bundle) ->
-                  withOpenTemp $ \(hat,at) -> do
-                    hPutDocLn hat $ bundle
-                    hClose hat
-                    return [ ('b', renderString content) , ('a', at) ]
-                Nothing ->
-                    return [ ('b', renderString body) ]
-     let ftable = [ ('t',addressOnly t),('c',cc),('f',f),('s',s) ] ++ ftable'
-     r <- execSendmail ftable scmd fn
-     when (r /= ExitSuccess) $ fail ("failed to send mail to: " ++ t
-                                     ++ "\nPerhaps sendmail is not configured.")
+      generateEmail h f t s cc body
+      hClose h
+      withOpenTemp $ \(hat,at) -> do
+        ftable' <- case mbundle of
+                   Just (content,bundle) -> do
+                       hPutDocLn hat $ bundle
+                       return [ ('b', renderString content) , ('a', at) ]
+                   Nothing ->
+                       return [ ('b', renderString body) ]
+        hClose hat
+        let ftable = [ ('t',addressOnly t),('c',cc),('f',f),('s',s) ] ++ ftable'
+        r <- execSendmail ftable scmd fn
+        when (r /= ExitSuccess) $ fail ("failed to send mail to: " ++ t
+                                       ++ "\nPerhaps sendmail is not configured.")
   else if have_mapi then do
      r <- withCString t $ \tp ->
            withCString f $ \fp ->
@@ -568,13 +573,13 @@ verifyPS (Verify pks:_) ps = verifyGPG pks ps
 verifyPS (VerifySSL auks:_) ps = verifySSL auks ps
 verifyPS (_:os) ps = verifyPS os ps
 
-verifyGPG :: FilePath -> PackedString -> IO (Maybe PackedString)
+verifyGPG :: AbsolutePath -> PackedString -> IO (Maybe PackedString)
 verifyGPG goodkeys s =
     withOpenTemp $ \(th,tn) -> do
       hPutPS th s
       hClose th
       rval <- exec "gpg"  ["--batch","--no-default-keyring",
-                           "--keyring",fix_path goodkeys, "--verify"]
+                           "--keyring",fix_path $ toFilePath goodkeys, "--verify"]
                            (File tn, Null, Null)
       case rval of
           ExitSuccess -> return $ Just gpg_fixed_s
@@ -595,7 +600,7 @@ verifyGPG goodkeys s =
             fix_path p = p
 #endif
 
-verifySSL :: FilePath -> PackedString -> IO (Maybe PackedString)
+verifySSL :: AbsolutePath -> PackedString -> IO (Maybe PackedString)
 verifySSL goodkeys s = do
     certdata <- opensslPS ["smime", "-pk7out"] s
                 >>= opensslPS ["pkcs7", "-print_certs"]
@@ -603,7 +608,7 @@ verifySSL goodkeys s = do
     let key_used = concatPS $ tail $
                    takeWhile (/= packString"-----END PUBLIC KEY-----")
                            $ linesPS cruddy_pk
-        in do allowed_keys <- linesPS `liftM` readFilePS goodkeys
+        in do allowed_keys <- linesPS `liftM` readFilePS (toFilePath goodkeys)
               if not $ key_used `elem` allowed_keys
                 then return Nothing -- Not an allowed key!
                 else withTemp $ \cert ->
@@ -635,9 +640,16 @@ can_execute (arg,expected_return_value) exe = do
   - or -1 if color output not supported or error occured.
   - Terminal type determined by TERM env. variable.
   -}
-getTermNColors :: IO CInt
+getTermNColors :: IO Int
 
-#ifdef HAVE_CURSES
+#ifdef HAVE_TERMINFO
+getTermNColors = do                          
+  t <- setupTermFromEnv                      
+  return $ case getCapability t $ tiGetNum "colors" of
+    Nothing -> (-1)                          
+    Just x -> x
+
+#elif HAVE_CURSES
 
 foreign import ccall "tgetnum" c_tgetnum :: CString -> IO CInt
 foreign import ccall "tgetent" c_tgetent :: Ptr CChar -> CString -> IO CInt
@@ -651,10 +663,11 @@ getTermNColors = if not use_color
                          allocaBytes termioBufSize (getTermNColorsImpl term)
                       `catch` \_ -> return (-1)
 
-getTermNColorsImpl :: String -> Ptr CChar -> IO CInt
+getTermNColorsImpl :: String -> Ptr CChar -> IO Int
 getTermNColorsImpl term buf = do rc <- withCString term $
                                        \termp -> c_tgetent buf termp
-                                 if (rc /= 1) then return (-1)  else withCString "Co" $ \capap -> c_tgetnum capap
+                                 x <- if (rc /= 1) then return (-1)  else withCString "Co" $ \capap -> c_tgetnum capap
+                                 return $ fromIntegral x
 
 #else
 
