@@ -129,6 +129,10 @@ import qualified Data.ByteString as B
 import qualified Data.ByteString.Char8 as BC
 import qualified Data.ByteString.Internal as BI
 import qualified Data.ByteString.Unsafe as BU
+#if HAVE_HASKELL_ZLIB
+import qualified Data.ByteString.Lazy as BL
+import qualified Codec.Compression.GZip as GZ
+#endif
 
 debugForeignPtr :: ForeignPtr a -> String -> IO ()
 #ifdef DEBUG_PS
@@ -514,6 +518,7 @@ writeFilePS = B.writeFile
 -- | Read an entire file, which may or may not be gzip compressed, directly
 -- into a 'PackedString'.
 
+#ifndef HAVE_HASKELL_ZLIB
 foreign import ccall unsafe "static zlib.h gzopen" c_gzopen
     :: CString -> CString -> IO (Ptr ())
 foreign import ccall unsafe "static zlib.h gzclose" c_gzclose
@@ -522,6 +527,7 @@ foreign import ccall unsafe "static zlib.h gzread" c_gzread
     :: Ptr () -> Ptr Word8 -> CInt -> IO CInt
 foreign import ccall unsafe "static zlib.h gzwrite" c_gzwrite
     :: Ptr () -> Ptr Word8 -> CInt -> IO CInt
+#endif
 
 gzReadFilePS :: FilePath -> IO PackedString
 gzReadFilePS f = do
@@ -533,6 +539,14 @@ gzReadFilePS f = do
        else do hSeek h SeekFromEnd (-4)
                len <- hGetLittleEndInt h
                hClose h
+#ifdef HAVE_HASKELL_ZLIB
+               -- for now we ignore the length, but zlib will be modified
+               -- to add an API to say what length the result will be so
+               -- that BL.toChunks only produces one chunk, which in turn
+               -- means that B.concat won't need to copy data
+               -- the dummy use of len is to avoid a compiler warning
+               liftM (B.concat . BL.toChunks . const GZ.decompress len) $ BL.readFile f -- ratify readFile: immediately consumed by the conversion to a strict bytestring
+#else
                withCString f $ \fstr-> withCString "rb" $ \rb-> do
                  gzf <- c_gzopen fstr rb
                  when (gzf == nullPtr) $ fail $ "problem opening file "++f
@@ -544,6 +558,7 @@ gzReadFilePS f = do
                  when (fromIntegral lread /= len) $
                       fail $ "problem gzreading file "++f
                  return $ BI.fromForeignPtr fp 0 len
+#endif
 
 hGetLittleEndInt :: Handle -> IO Int
 hGetLittleEndInt h = do
@@ -558,6 +573,9 @@ gzWriteFilePS f ps = gzWriteFilePSs f [ps]
 
 gzWriteFilePSs :: FilePath -> [PackedString] -> IO ()
 gzWriteFilePSs f pss  =
+#ifdef HAVE_HASKELL_ZLIB
+    BL.writeFile f $ GZ.compress $ BL.fromChunks pss
+#else
     withCString f $ \fstr -> withCString "wb" $ \wb -> do
     gzf <- c_gzopen fstr wb
     when (gzf == nullPtr) $ fail $ "problem gzopening file for write: "++f
@@ -571,6 +589,7 @@ gzWriteToGzf gzf ps = case BI.toForeignPtr ps of
     lw <- withForeignPtr x $ \p -> c_gzwrite gzf (p `plusPtr` s)
                                                  (fromIntegral l)
     when (fromIntegral lw /= l) $ fail $ "problem in gzWriteToGzf"
+#endif
 
 -- -----------------------------------------------------------------------------
 -- mmapFilePS
