@@ -178,11 +178,6 @@ unsafeWithInternals (PS fp s l) f
 (!) :: PackedString -> Int -> Word8
 (PS x s _l) ! i
     = unsafePerformIO $ withForeignPtr x $ \p -> peekElemOff p (s+i)
-#ifndef __HADDOCK__
-  -- | i < 0 = error "Can't access negative element in PackedString."
-  -- | i >= l = error "Out of range element in PackedString."
-  -- | otherwise = unsafePerformIO $ withForeignPtr x $ \p -> peekElemOff p (s+i)
-#endif
 
 -- -----------------------------------------------------------------------------
 -- generatePS
@@ -215,9 +210,9 @@ instance Ord PackedString where
 -- | 'comparePS' provides an 'Ordering' for 'PackedStrings' supporting slices.
 comparePS :: PackedString -> PackedString -> Ordering
 comparePS (PS _ _ 0) (PS _ _ 0) = EQ    -- short cut for empty strings
-comparePS (PS x1 s1 l1) (PS x2 s2 l2) = unsafePerformIO $ 
-    withForeignPtr x1 $ \p1 -> 
-        withForeignPtr x2 $ \p2 -> do 
+comparePS (PS x1 s1 l1) (PS x2 s2 l2) = unsafePerformIO $
+    withForeignPtr x1 $ \p1 ->
+        withForeignPtr x2 $ \p2 -> do
             i <- c_memcmp (p1 `plusPtr` s1) (p2 `plusPtr` s2)
                  (fromIntegral $ min l1 l2)
             return $ case i `compare` 0 of
@@ -340,19 +335,19 @@ unsafeHeadPS (PS x s _) -- ps ! 0 is inlined manually to eliminate a (+0)
 -- | Extract the elements after the head of a packed string, which must be non-empty.
 {-# INLINE tailPS #-}
 tailPS :: PackedString -> PackedString
-tailPS (PS p s l) 
+tailPS (PS p s l)
     | l <= 0    = error ("FastPackedString.tailPS: empty list")
-    | l == 1    = nilPS                                                                    
+    | l == 1    = nilPS
     | otherwise = PS p (s+1) (l-1)
 
 -- | Return all the elements of a packed string except the last one.
 -- The string must be finite and non-empty.
 {-# INLINE initPS #-}
 initPS :: PackedString -> PackedString
-initPS (PS p s l) 
+initPS (PS p s l)
     | l <= 0    = error ("FastPackedString.initPS: empty list")
-    | l == 1    = nilPS                                                                    
-    | otherwise = PS p s (l-1)                                                          
+    | l == 1    = nilPS
+    | otherwise = PS p s (l-1)
 
 {-# INLINE unsafeTailPS #-}
 unsafeTailPS :: PackedString -> PackedString
