@@ -25,10 +25,10 @@ import Data.IORef ( IORef, newIORef, readIORef, modifyIORef )
 import Darcs.SignalHandler ( catchNonSignal )
 import Workaround ( createDirectoryIfMissing )
 import Darcs.Utils ( withCurrentDirectory, breakCommand, prettyException, catchall )
-import Darcs.Global ( atexit, sshControlMasterDisabled, darcsdir )
+import Darcs.Global ( atexit, sshControlMasterDisabled, darcsdir, withDebugMode )
 import Darcs.Lock ( withTemp, withOpenTemp, tempdir_loc, removeFileMayNotExist )
 import Exec ( exec, Redirects, Redirect(..), )
-import Darcs.Progress ( debugMessage, debugFail, progressList )
+import Darcs.Progress ( withoutProgress, debugMessage, debugFail, progressList )
 
 import FastPackedString ( PackedString, unpackPS, readFilePS, writeFilePS, hGetPS )
 #include "impossible.h"
@@ -41,13 +41,15 @@ data Connection = C { inp :: !Handle, out :: !Handle, err :: !Handle, deb :: Str
 
 withSSHConnection :: String -> (Connection -> IO a) -> IO a -> IO a
 withSSHConnection x withconnection withoutconnection =
+    withoutProgress $
     do cs <- readIORef sshConnections
        let uhost = takeWhile (/= ':') x
            url = cleanrepourl x
        case lookup url (cs :: Map String (Maybe Connection)) of
          Just Nothing -> withoutconnection
          Just (Just c) -> withconnection c
-         Nothing -> do (ssh,sshargs_) <- getSSHOnly SSH
+         Nothing ->
+           do mc <- do (ssh,sshargs_) <- getSSHOnly SSH
                        let sshargs = sshargs_ ++ [uhost,"darcs","transfer-mode","--repodir",cleanrepodir x]
                        debugMessage $ "ssh "++unwords sshargs
                        (i,o,e,_) <- runInteractiveProcess ssh sshargs Nothing Nothing
@@ -58,12 +60,18 @@ withSSHConnection x withconnection withoutconnection =
                        let c = C { inp = i, out = o, err = e,
                                    deb = \s -> debugMessage ("with ssh "++uhost++": "++s) }
                        modifyIORef sshConnections (insert url (Just c))
-                       withconnection c
+                       return $ Just c
                     `catchNonSignal`
                             \e -> do debugMessage $ "Failed to start ssh connection:\n    "++
                                                     prettyException e
                                      severSSHConnection x
-                                     withoutconnection
+                                     debugMessage $ unlines $
+                                         [ "NOTE: the server may be running a version of darcs prior to 2.0.0."
+                                         , ""
+                                         , "Installing darcs 2 on the server will speed up ssh-based commands."
+                                         ]
+                                     return Nothing
+              maybe withoutconnection withconnection mc
 
 severSSHConnection :: String -> IO ()
 severSSHConnection x = do debugMessage $ "Severing ssh failed connection to "++x
@@ -108,10 +116,15 @@ grabSSH x c = do
                                  [] -> failwith "An error occurred"
                        else failwith "Error"
 
+sshStdErrMode :: IO Redirect
+sshStdErrMode = withDebugMode $ \amdebugging ->
+                return $ if amdebugging then AsIs else Null
+
 copySSH :: String -> FilePath -> IO ()
 copySSH uRaw f = withSSHConnection uRaw (\c -> grabSSH uRaw c >>= writeFilePS f) $
               do let u = escape_dollar uRaw
-                 r <- runSSH SCP u [] [u,f] (AsIs,AsIs,AsIs)
+                 stderr_behavior <- sshStdErrMode
+                 r <- runSSH SCP u [] [u,f] (AsIs,AsIs,stderr_behavior)
                  when (r /= ExitSuccess) $
                       debugFail $ "(scp) failed to fetch: " ++ u
     where {- '$' in filenames is troublesome for scp, for some reason.. -}
@@ -133,7 +146,8 @@ copySSHs u ns d =
          withTemp $ \sftpoutput ->
          do hPutStr th input
             hClose th
-            r <- runSSH SFTP u [] [host] (File tn, File sftpoutput, AsIs)
+            stderr_behavior <- sshStdErrMode
+            r <- runSSH SFTP u [] [host] (File tn, File sftpoutput, stderr_behavior)
             let files = if length ns > 5
                           then (take 5 ns) ++ ["and "
                                ++ (show (length ns - 5)) ++ " more"]
