@@ -59,17 +59,6 @@ mkpath 'd.d/';
 touch 'd.d/foo';
 like(darcs(qw(add -rv d.d)), qr/d.d\/foo/,$test_name);
 
-TODO: {
-    local $TODO = 'waiting on coding';
-    my $test_name = "add should fail on files it can't read (because it would fail to record it later anyway).";
-    touch "no_perms.txt";
-    chmod(0000,"no_perms.txt");
-    like(darcs(qw(add no_perms.txt)), qr/permission denied/,$test_name);
-    rm_rf "no_perms.txt";
-
-}
-
-
 {
     my $test_name = 'adding a non-existent dir and file gives the expected message';
     my $out = darcs(qw!add notadir/notafile!);
