@@ -3,15 +3,14 @@
 # Some tests for 'darcs whatsnew '
 
 use lib 'lib/perl';
-use Test::More qw/no_plan/;
+use Test::More 'no_plan';
 use Shell::Command;
 use Test::Darcs;
 use strict;
 
-cleanup 'temp1';
-mkpath 'temp1';
-chdir 'temp1';
-darcs 'init';
+
+init_tmp_repo();
+
 touch('look_summary.txt');
 
 {
@@ -26,11 +25,3 @@ touch('look_summary.txt');
     close(FOO);
     like( darcs('whatsnew -sl'), qr!disable!i, $test_name);
 }
-
-chdir '../';
-#rm_rf('temp1');
-#ok((!-d 'temp1'), 'temp1 directory was deleted');
-
-
-
-
