@@ -14,7 +14,3 @@ touch('foo');
 darcs("add foo");
 like( darcs("record -a -m add_foo"), qr/finished recording/i, 'added patch');
 
-TODO: {
-    local $TODO = "needs fixed on FreeBSD" if ($^O eq 'freebsd');
-    unlike( darcs("dist -v"), qr/error/i, "darcs dist -v avoids error message " );
-}
