@@ -30,9 +30,6 @@ lookfor readFile \
 lookfor hGetContents \
         "hGetContents doesn't ensure the file is closed before it is deleted!"
 
-lookfor HopefullyPrivate \
-    "HopefullyPrivate should not be imported anywhere but Hopefully.  It's private!"
-
 # look for tabs in haskell source
 rm -f "$RESULT"
 darcs query manifest --repodir="$ROOT" | grep '\.l\?hs$' | while read f; do
