@@ -43,8 +43,3 @@ my $out = darcs 'rec -A bar -am "add extra line"';
 like(darcs(q( push -a)) ,qr/conflicts/i,'expect conflicts when pushing');  
 chdir '../tmp1';
 
-TODO: {
-    local $TODO = 'waiting on code to fix this';
-    unlike(darcs(q(resolve)),qr/no conflicts/i, "after a conflict, darcs resolve should report a conflict");
-}
-
