@@ -50,8 +50,14 @@ darcs "pull --all ../tmp2";
 # we should have a marked conflict now.
 # we resolve it simply by removing conflict markers.
 
-# I'm too lazy to translate this to Perl right now. 
-`grep -v '\(\^ \^\|\*\*\|v v\)' A > tmp`;
+open(A, "A") || die;
+open(TMP, ">tmp") || die;
+while (<A>) {
+       (/\^ \^|\*\*|v v/) or print TMP;
+}
+close(A);
+close(TMP);
+
 mv('tmp','A');
 
 darcs "record -m 'mark-conflicts' --all";
