@@ -5,6 +5,18 @@ set -ev;
 ## I would use the builtin !, but that has the wrong semantics.
 not () { "$@" && exit 1 || :; }
 
+# darcs does not support cygwin paths (/cygdrive/c/foo), so if
+# we want to run the test suite under Cygwin Bash, we must
+# convert accordingly
+portable_pwd () {
+  if uname | grep -qi cygwin ; then
+    cygpath -w `pwd`
+  else
+    pwd
+  fi
+}
+
+
 rm -rf temp1 temp2
 
 mkdir temp1
@@ -28,7 +40,7 @@ cd ../..  # now in temp2
 darcs add one;
 darcs record --patch-name uno --all
 cd ..     # now outside of any repo
-darcs pull --repodir temp1 --all ../temp2 | grep -i 'Finished pulling.' # temp2 is relative to temp1
+darcs pull --repodir temp1 --all temp2 | grep -i 'Finished pulling.' # temp2 is not relative to temp1
 
 # set up server repo
 date > temp2/one/date.t
@@ -36,19 +48,18 @@ darcs add --repodir ./temp2 one/date.t
 darcs record --repodir ./temp2 -a -m foo
 
 # set up client repo for failure
-chmod a-rwx ./temp1/one # remove all permissions
-not darcs pull --repodir ./temp1 -a 2> err
-chmod u+rwx temp1/one # restore permission
-cat err
-rm -rf temp1/one
 if echo $OS | grep -i windows; then
-    echo this test does not work on windows, so ignore it
+    echo this test does not work on windows because it
+    echo is not possible to chmod -r
+elif whoami | grep root; then
+    echo root never gets permission denied
 else
-    if whoami | grep root; then
-        echo root never gets permission denied
-    else
-        grep 'permission denied' err
-    fi
+    chmod a-rwx ./temp1/one # remove all permissions
+    not darcs pull --repodir ./temp1 -a 2> err
+    chmod u+rwx temp1/one # restore permission
+    cat err
+    grep 'permission denied' err
+    rm -rf temp1/one
 fi
 
 cd temp1
@@ -57,12 +68,13 @@ echo Before trying to pull from self, defaultrepo is something else
 not grep temp1 _darcs/prefs/defaultrepo
 
 #return special message when you try to pull from yourself
-DIR=`pwd`
-not darcs pull -a "$DIR" 2> out
+IFS=""
+DIR=`portable_pwd`
+not darcs pull --debug -a "$DIR" 2> out
 cat out
 grep 'Can.t pull from current repository' out
 
-not darcs pull -a . 2> out
+not darcs pull --debug -a . 2> out
 cat out
 grep 'Can.t pull from current repository' out
 
@@ -73,10 +85,10 @@ rm -f _darcs/prefs/defaultrepo
 not darcs pull 2> err
 grep 'please specify one' err
 echo . > _darcs/prefs/defaultrepo
-not darcs pull 2> err
+not darcs pull --debug 2> err
 grep 'Can.t pull from current repository' err
 
-not darcs pull ../* 2> out
+not darcs pull --debug ../* 2> out
 cat out
 not grep 'Can.t pull from current repository' out
 cd .. # now outside of any repo
@@ -96,8 +108,8 @@ cd temp2
 sleep 1 # So that rollback won't have same timestamp as get.
 darcs rollback -p BB -a -m unB
 darcs revert -a
-darcs pull -a ../temp1 2> err
-not grep 'Error applying patch' err
+darcs pull -a ../temp1 2> err2
+not grep 'Error applying patch' err2
 cd ..
 
 cd temp1
@@ -123,11 +135,11 @@ darcs add newdir
 darcs record -am newdir
 cd ../temp2
 mkdir newdir
-darcs pull -a ../temp1 &> out
+darcs pull -a ../temp1 &> out2
 cat out
-grep Backing out
-grep 'Finished pulling' out
-grep newdir out
+grep Backing out2
+grep 'Finished pulling' out2
+grep newdir out2
 cd ..
 
 rm -rf temp1 temp2
