@@ -41,7 +41,7 @@ chdir '../';
     darcs "record --patch-name 'uno' --all";
     chdir '../';     # now outside of any repo
 
-    like(darcs(qw!push --repodir temp2 --all "../temp1"!), # temp2 is relative to temp1
+    like(darcs(qw!push --repodir temp2 --all "temp1"!), # temp2 is not relative to temp1
             qr/Finished apply./i, $test_name);
 }
 
