@@ -12,9 +12,13 @@ use warnings;
 use File::Slurp 'append_file';
 use File::Temp 'tempdir';
 
+if ($^O =~ /win/i or $^O =~ /msys/i) {
+  pass 'test does not work on windows';
+} else {
 # test_with_format('--old-fashioned-inventory'); known not to work. 
 test_with_format('--darcs-2');
 test_with_format('--hashed');
+}
 
 sub test_with_format {
     my $format = shift;
@@ -38,7 +42,6 @@ sub test_with_format {
     darcs "record -am 'new patch'";
     my $out = darcs "push -a ../r1";
     like($out, qr/failed/, "expect failure when pushing to a repo with unwritable inventory (format: $format)");
-
     chdir '../../'; # move out the way for auto-tmpdir cleanup. 
 }
 
