@@ -21,7 +21,7 @@ darcs record -a -m add_foo_bar -A x
 darcs send --author=me -a --to=random@random --sendmail-command='grep "^To: random@random$" %<' ../temp2
 
 # Test that a default preference will be used when no --to value is specified
-echo "default@email" > ../temp2/_darcs/prefs/email 
+echo "default@email" > ../temp2/_darcs/prefs/email
 darcs send --author=me -a --sendmail-command='grep "^To: default@email$" %<' ../temp2
 
 # Test that the --to parameter overrides the default value in the repository
@@ -34,5 +34,17 @@ darcs send --author=me -a --subject="it works" --output test1.dpatch ../temp2
 darcs send --author=me -a --subject="it works" --output-auto-name ../temp2
 cmp test1.dpatch add_foo_bar.dpatch
 
+# test --output-auto-name works with optional argument.
+mkdir patchdir
+darcs send --author=me -a --subject="it works" --output-auto-name=patchdir ../temp2
+cmp test1.dpatch patchdir/add_foo_bar.dpatch
+
+# checking --output-auto-name=dir when run in different directory
+cd patchdir
+rm add_foo_bar.dpatch
+darcs send --author=me -a --subject="it works" --output-auto-name=. ../../temp2
+cmp ../test1.dpatch add_foo_bar.dpatch
+cd ..
+
 cd ..
 rm -rf temp1 temp2
