@@ -11,7 +11,7 @@ use Cwd 'abs_path';
 
 my $test_dir = abs_path();
 
-if ($^O =~ /win/i) {
+if ($^O =~ /win/i or $^O =~ /msys/i) {
     pass 'test does not work on windows';
 } else {
     my $test_name = 'darcs pull --set-scripts-executable works';
